import { Button, TextArea } from "devextreme-react";
import { useCallback, useEffect, useState } from "react";
import ActionSheet, { ActionSheetTypes } from "devextreme-react/action-sheet";
import logos from "../../../public/images/shore-logo-1.png";
//import { removeUndefinedProperties } from "../utils";
import Image from "next/image";
import { ChatProps } from "./types";

const newMessage = {
  msg: "",
};

const CollaborationChats = (props: ChatProps) => {
  const { clientId, taskId, data, sendProps } = props;
  const { mutate, isLoading, isSuccess } = sendProps || {};
  const [newMessageData, setNewMessageData] = useState<any>({
    ...newMessage,
  });
  const [isActionSheetVisible, setIsActionSheetVisible] = useState(false);
  const [showReplyUI, setShowreplyUI] = useState(false);
  const [selectedText, setSelectedText] = useState("");
  const [actionSheetTarget, setActionSheetTarget] = useState<
    HTMLElement | string
  >("");
  const actionSheetItems = [{ text: "Reply" }, { text: "Delete" }];

  const updateField = (field: string) => (value: any) => {
    setNewMessageData({ ...newMessage, ...{ [field]: value } });
  };

  useEffect(() => {
    if (isSuccess) {
      setNewMessageData({ ...newMessage });
    }
  }, [isSuccess]);

  const onListItemClick = useCallback(
    (e: any) => {
      setShowreplyUI(false);
      setIsActionSheetVisible(true);
      setActionSheetTarget(e.target);
      setSelectedText(e.target.innerText);
    },
    [setIsActionSheetVisible, setActionSheetTarget]
  );

  const onActionSheetItemClick = useCallback(
    (e: ActionSheetTypes.ItemClickEvent) => {
      if (e?.itemData?.text === "Reply") {
        setShowreplyUI(true);
      }
    },
    []
  );

  const onVisibleChange = useCallback(
    (isVisible: boolean) => {
      if (isVisible !== isActionSheetVisible) {
        setIsActionSheetVisible(isVisible);
      }
    },
    [setIsActionSheetVisible, isActionSheetVisible]
  );

  const cancelReplyUI = () => {
    setShowreplyUI(false);
  };
  const handleFormSubmit = useCallback(() => {
    if (!newMessageData.msg) return;
    newMessageData["client_id"] = clientId;
    newMessageData["task_id"] = taskId;
    newMessageData["title"] = "dev";
    newMessageData["client_name"] = clientId ? "RentalBeast" : null;
    newMessageData["task_name"] = taskId ? "Rb test 100 urls" : null;
    newMessageData["user"] = "RB";
    newMessageData["is_master"] = true;
    mutate(newMessageData);
  }, [clientId, mutate, newMessageData, taskId]);

  const renderChats = () => {
    return (
      <ol className="chat">
        {data?.map((chat: any, index: number) => {
          return (
            <li key={index} className={chat?.user === "RB" ? "me" : "them"}>
              <div className="chat-info">
                <small>
                  {chat?.user} {chat?.date}
                </small>
              </div>
              <div className="chat-msgblock">
                <span className="user-icon">{chat?.user}</span>
                <blockquote onClick={onListItemClick}>{chat?.msg}</blockquote>
              </div>
            </li>
          );
        })}
      </ol>
    );
  };

  return (
    <div className="collaborationChat">
      {/* <h6>
        <em>July 23, 2013 </em> 7:51 PM
      </h6> */}
      {renderChats()}
      <ActionSheet
        title="Action"
        usePopover={true}
        visible={isActionSheetVisible}
        target={actionSheetTarget}
        items={actionSheetItems}
        onItemClick={onActionSheetItemClick}
        onVisibleChange={onVisibleChange}
      />
      {showReplyUI ? (
        <div className={`reply_UI ${showReplyUI ? "margincss" : ""}`}>
          <blockquote>
            <Image
              src={logos}
              alt="Logo"
              className="polarisLogo"
              style={{ width: "30px", height: "30px" }}
            />
            {selectedText}
          </blockquote>
          <Button
            type="default"
            text={"Cancel"}
            stylingMode="outlined"
            onClick={cancelReplyUI}
          />
        </div>
      ) : null}
      <div className={`action_block ${showReplyUI ? "margincss" : ""}`}>
        <TextArea
          label={showReplyUI ? "" : "Type a message"}
          width={"100%"}
          stylingMode="outlined"
          value={newMessageData.msg}
          onValueChange={updateField("msg")}
        />
        <Button
          type="default"
          text={isLoading ? "Sending..." : "Send"}
          stylingMode="contained"
          onClick={handleFormSubmit}
        />
      </div>
    </div>
  );
};

export default CollaborationChats;