import { DataGridTypes } from "devextreme-react/data-grid";
import SelectBox from "devextreme-react/select-box";
import TextBox from "devextreme-react/text-box";

export const STATUS_LIST = [
  'Active',
  'InActive'
];

export const cellNameRender = (cell: DataGridTypes.ColumnCellTemplateData) => (
  <div className="name-template">
    <div>{cell.data.clientName || cell.data.name }</div>
    <div className="position">{cell.data.position}</div>
  </div>
);

export const cellClientNameRender = (cell: DataGridTypes.ColumnCellTemplateData) => (
  <div className="name-template">
    <div>{cell.data.clientName}</div>
    <div className="position">{cell.data.position}</div>
  </div>
);

export const cellNameCombine = (cell: DataGridTypes.ColumnCellTemplateData) => {
  const { firstName, lastName } = cell.data; 
  const fullName = `${firstName} ${lastName}`;

  return (
    <div className="name-template">
      <div>{fullName}</div>
      <div className="position">{cell.data.position}</div>
    </div>
  );
};


export const cellUrlNameRender = (cell: DataGridTypes.ColumnCellTemplateData) => (
  <div className="name-template">
    <div>{cell.data.className}</div>
    <div className="position">{cell.data.position}</div>
  </div>
);


export const editCellStatusRender = () => (
  <SelectBox
    className="cell-info"
    dataSource={STATUS_LIST}
    itemRender={ContactStatus}
    fieldRender={fieldRender}
  />
);

export const cellPhoneRender = (cell: DataGridTypes.ColumnCellTemplateData) =>
  String(cell.data.phone).replace(/(\d{3})(\d{3})(\d{4})/, "+1($1)$2-$3");

export const cellLastExecutionTime = (cell: DataGridTypes.ColumnCellTemplateData) => {
  if(cell.data.latest_execution === "-") {
    return '---';
  }
  return formatDate(cell.data.latest_execution);
};

export const fieldRender = (text: string) => (
  <>
    <ContactStatus text={text} />
    <TextBox readOnly />
  </>
);

export const leadingZero = (num: number) => {
  return num < 10 ? `0${num}` : `${num}`;
};

export const formatDate = (dt: any) => {
  const date = new Date(dt);
  const year = date.getFullYear();
  const month = date.getMonth() + 1; 
  const day = date.getDate();
  const hours = date.getHours();
  const minutes = date.getMinutes();
  return `${leadingZero(month)}/${leadingZero(day)}/${year}:  ${leadingZero(hours)}:${leadingZero(minutes)}`;
};


export const cellStartTime = (cell: DataGridTypes.ColumnCellTemplateData) => {
  if(cell.data.starttime === "" || cell.data.timestamp === "") {
    return '---';
  }
  return formatDate(cell.data.starttime || cell.data.timestamp);
};

export const cellEndTime = (cell: DataGridTypes.ColumnCellTemplateData) => {
  if(cell.data.endTime === "") {
    return '---';
  }
  return formatDate(cell.data.endTime);
};

export const cellTimeStamp = (cell: DataGridTypes.ColumnCellTemplateData) => {
  if(cell.data.timeStamp === "") {
    return '---';
  }
  return formatDate(cell.data.timeStamp);
};

export const cellComplexityRender = (cell: DataGridTypes.ColumnCellTemplateData) => (
  <div className="name-template">
    <div>{cell.data?.complexity || 'Low'}</div>
    <div className="position">{cell.data.position}</div>
  </div>
);

export const ContactStatus = ({ text, contentClass = '', showText = true }: { text: string, contentClass?: string, showText?: boolean }) => (
  <div className={`status status-contact status-${text?.toLowerCase()} ${contentClass}`}>
    <span>{showText ? text : ''}</span>
  </div>
);