import React, { ReactNode } from "react";
import Button from "devextreme-react/button";
import Toolbar, { Item } from "devextreme-react/toolbar";
import { useRouter } from "next/navigation";

type ToolbarAnalyticsProps = {
  title: string;
  additionalToolbarContent?: ReactNode;
};

const ToolbarAnalytics = ({
  title,
  additionalToolbarContent,
  children,
}: React.PropsWithChildren<ToolbarAnalyticsProps>) => {
  const router = useRouter();

  const handleBackButtonClick = () => {
    router.back();
  };
  return (
    <div className="view-wrapper view-wrapper-dashboard">
      <Toolbar className="theme-dependent">
        <Item location="before">
          <Button
            icon="back"
            id="icon-back"
            onClick={handleBackButtonClick}
            className="back-button"
          />
        </Item>
        <Item location="before">
          <span className="toolbar-header">{title}</span>
        </Item>
        {additionalToolbarContent}
        <Item
          location="after"
          locateInMenu="auto"
          widget="dxButton"
          showText="inMenu"
        >
          <Button text="Refresh" icon="refresh" stylingMode="text" />
        </Item>
        <Item location="after" locateInMenu="auto">
          <div className="separator" />
        </Item>
        <Item
          location="after"
          locateInMenu="auto"
          widget="dxButton"
          showText="inMenu"
        >
          <Button icon="export" text="Export" stylingMode="text" />
        </Item>
      </Toolbar>
      {children}
    </div>
  );
};

export default ToolbarAnalytics;