import { navigation } from "../fixtures/app-navigation";
import SideNavOuterToolbar from "../components/side-nav-outer-toolbar/SideNavOuterToolbar";
import ToolbarAnalytics from "../components/toolbar-analytics/ToolbarAnalytics";
import PsAccordion from "../components/accordion/Accordion";
import { CustomItem } from "../components/accordion/UIComponent";
import { FormPopup, FormTextbox } from "../components";
import { useCallback, useState } from "react";
import PsButton from "../components/button/Button";
import PsMenu from "../components/menu/Menu";
import { ProductItemType } from "../components/menu/types";

const companies = [
  {
    ID: 1,
    title: "Super Mart of the West",
    Address: "702 SW 8th Street",
    City: "Bentonville",
    State: "Arkansas",
    Zipcode: 72716,
    Phone: "(800) 555-2797",
    Fax: "(800) 555-2171",
    Website: "http://www.nowebsitesupermart.dx",
  },
  {
    ID: 2,
    title: "Electronics Depot",
    Address: "2455 Paces Ferry Road NW",
    City: "Atlanta",
    State: "Georgia",
    Zipcode: 30339,
    Phone: "(800) 595-3232",
    Fax: "(800) 595-3231",
    Website: "http://www.nowebsitedepot.dx",
  },
  {
    ID: 3,
    title: "K&S Music",
    Address: "1000 Nicllet Mall",
    City: "Minneapolis",
    State: "Minnesota",
    Zipcode: 55403,
    Phone: "(612) 304-6073",
    Fax: "(612) 304-6074",
    Website: "http://www.nowebsitemusic.dx",
  },
  {
    ID: 4,
    title: "Tom's Club",
    Address: "999 Lake Drive",
    City: "Issaquah",
    State: "Washington",
    Zipcode: 98027,
    Phone: "(800) 955-2292",
    Fax: "(800) 955-2293",
    Website: "http://www.nowebsitetomsclub.dx",
  },
];

const newContact = {
  name: "",
  phone: "",
};

const newPopupForm = {
  firstName: "",
  lastName: "",
};

const products = [
  {
    id: "1",
    name: "Video Players",
    items: [
      {
        id: "1_1",
        name: "HD Video Player",
        price: 220,
        icon: "images/products/1.png",
      },
      {
        id: "1_2",
        name: "SuperHD Video Player",
        icon: "images/products/2.png",
        price: 270,
      },
    ],
  },
  {
    id: "2",
    name: "Televisions",
    items: [
      {
        id: "2_1",
        name: "SuperLCD 42",
        icon: "images/products/7.png",
        price: 1200,
      },
      {
        id: "2_2",
        name: "SuperLED 42",
        icon: "images/products/5.png",
        price: 1450,
      },
      {
        id: "2_3",
        name: "SuperLED 50",
        icon: "images/products/4.png",
        price: 1600,
      },
      {
        id: "2_4",
        name: "SuperLCD 55 (Not available)",
        icon: "images/products/6.png",
        price: 1350,
        disabled: true,
      },
      {
        id: "2_5",
        name: "SuperLCD 70",
        icon: "images/products/9.png",
        price: 4000,
      },
    ],
  },
  {
    id: "3",
    name: "Monitors",
    items: [
      {
        id: "3_1",
        name: '19"',
        items: [
          {
            id: "3_1_1",
            name: "DesktopLCD 19",
            icon: "images/products/10.png",
            price: 160,
          },
        ],
      },
      {
        id: "3_2",
        name: '21"',
        items: [
          {
            id: "3_2_1",
            name: "DesktopLCD 21",
            icon: "images/products/12.png",
            price: 170,
          },
          {
            id: "3_2_2",
            name: "DesktopLED 21",
            icon: "images/products/13.png",
            price: 175,
          },
        ],
      },
    ],
  },
  {
    id: "4",
    name: "Projectors",
    items: [
      {
        id: "4_1",
        name: "Projector Plus",
        icon: "images/products/14.png",
        price: 550,
      },
      {
        id: "4_2",
        name: "Projector PlusHD",
        icon: "images/products/15.png",
        price: 750,
      },
    ],
  },
];

export default function MiddleWare() {
  const [newContactData, setNewContactData] = useState<any>({
    ...newContact,
  });

  const updateField = (field: string) => (value: any) => {
    setNewContactData({ ...newContactData, ...{ [field]: value } });
  };

  // form popup
  const [popupVisible, setPopupVisible] = useState(false);

  const changePopupVisibility = useCallback(() => {
    setPopupVisible(!popupVisible);
  }, [popupVisible]);

  const [newPopupData, setPopupData] = useState<any>({
    ...newPopupForm,
  });

  const updatePopupField = (field: string) => (value: any) => {
    setPopupData({ ...newPopupForm, ...{ [field]: value } });
  };

  const handleFormSubmit = useCallback(() => {
    console.log(newPopupData);
  }, [newPopupData]);

  // form popup end

  const itemClick = useCallback((itemData: ProductItemType) => {
    console.log(itemData);
  }, []);

  return (
    <SideNavOuterToolbar navigation={navigation} title={"Polaris"}>
      <ToolbarAnalytics title={"Demo"} />
      <PsAccordion dataSource={companies} Component={CustomItem} />
      <FormTextbox
        label="Organization Name"
        value={newContactData.name}
        isEditing={false}
        onValueChange={updateField("name")}
      />
      <FormTextbox
        value={newContactData.phone}
        isEditing={false}
        onValueChange={updateField("phone")}
        icon="tel"
        label="Phone"
        mask="+1(000)000-0000"
      />
      <PsButton text={"Submit"} onClick={() => console.log("submit")} />

      <PsButton text={"Popup Open"} onClick={changePopupVisibility} />
      <FormPopup
        title="New Client"
        visible={popupVisible}
        setVisible={changePopupVisibility}
        onSave={handleFormSubmit}
      >
        <FormTextbox
          label="First Name"
          value={newPopupForm.firstName}
          isEditing={false}
          onValueChange={updatePopupField("firstName")}
        />
        <FormTextbox
          label="Last Name"
          value={newPopupForm.lastName}
          isEditing={false}
          onValueChange={updatePopupField("lastName")}
        />
        <PsButton text={"Submit"} onClick={() => console.log("submit")} />
      </FormPopup>
      <PsMenu
        data={products}
        mode={"onClick"}
        displayExpr={"name"}
        orientation={"horizontal"}
        onItemClick={itemClick}
      />
    </SideNavOuterToolbar>
  );
}
